/*
 *	HeNCE Tool
 *
 *	comn.h - Global includes needed by everything.
 *
 *	Jun 1991  Robert Manchek  manchek@CS.UTK.EDU.
 *
 *	Revision Log
 *
$Log: comn.h,v $
 * Revision 1.1  1992/04/08  05:48:26  moore
 * initial RCS version
 *
 *
 */

#define	talloc(n,t) (t*)malloc((n)*sizeof(t))

int inColor;			/* are we on a binary screen */
int (*stop_mode)();		/* request to exit current display mode */
char *strsave();
enum { LANG_C = 0, LANG_FORTRAN } Language;
char *currentDirectory;

/*
 * The following are set from X resources
 */
char *editorCommand;	/* for editing text */
char *xtermCommand;		/* pathname where xterm resides */
char *henceLibDir;		/* where HeNCE's node library lives (for Makefiles) */
char *pvmLib;			/* where libpvm.a lives (for Makefiles) */
char *binDir;			/* where node binaries go (for Makefiles) */
char *includeDir;		/* where hence include files go (for Makefiles) */
char *pvmdExecPath;		/* location of pvmd binary on this machine */
char *pvmHostFile;		/* pathname of "master" pvm hosts file */
char *languageString;	/* either C or FORTRAN */
char *iconList;			/* name of file containing icons */
char *traceFileName;	/* name of default trace file */
char *subDefsFile;		/* name of sub.defs file */

/*
 * Local variables:
 * tab-width:4
 * End:
 */
